@@ -330,7 +330,7 @@ class MSData:
         self.intensityBPC = self.intensityBPC / np.max(self.intensityBPC) * 100
 
 
-    def plotBPC(self, pltName):
+    def plotBPC(self, pltName, fontsize=20, dpi=300):
         """
         Function to plot BPC.
 
@@ -338,13 +338,17 @@ class MSData:
         ----------------------------------------------------------
         pltName: str
             Name of the plot.
+        fontsize: int
+            Font size of the plot.
+        dpi: int
+            Resolution of the plot.
         """
 
-        plt.plot(self.rtBPC, self.intensityBPC, color="black", linewidth=1)
-        plt.xlabel("Retention time, min", fontname='Arial', fontsize=15, labelpad=5)
-        plt.ylabel("Intensity, %", fontname='Arial', fontsize=15, labelpad=5)
-        plt.xticks(fontname='Arial', fontsize=10)
-        plt.yticks(fontname='Arial', fontsize=10)
+        plt.plot(self.rtBPC, self.intensityBPC, color="black", linewidth=1, dpi=dpi)
+        plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=5)
+        plt.ylabel("Intensity, %", fontname='Arial', fontsize=fontsize, labelpad=5)
+        plt.xticks(fontname='Arial', fontsize=fontsize)
+        plt.yticks(fontname='Arial', fontsize=fontsize)
         plt.savefig(fname=pltName, bbox_inches='tight')
         plt.close()
 
@@ -840,7 +844,7 @@ def outputConfig(name, timePoints, gradient):
     df.to_csv(fname, index=False)
 
 
-def outputGradientFig(name, gradient, timePoints, fontsize=20):
+def outputGradientFig(name, gradient, timePoints, fontsize=20, dpi=600):
     """
     Function to output the gradient figure in png.
 
@@ -854,9 +858,11 @@ def outputGradientFig(name, gradient, timePoints, fontsize=20):
         Sequence of time points.
     fontsize: int
         Font size of the figure.
+    dpi: int
+        Resolution of the figure.
     """
 
-    plt.plot(timePoints, gradient, color="black", linewidth=1)
+    plt.plot(timePoints, gradient, color="black", linewidth=1, dpi=dpi)
     plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=2)
     plt.ylabel("Mobile phase, %", fontname='Arial', fontsize=fontsize, labelpad=2)
     plt.xticks(fontname='Arial', fontsize=fontsize)
